@@ -14,7 +14,6 @@ parameter_types = [
     "metadata_table",
     "boolean",
     "connection",
-    "group",
     "text",
     "int",
     "string",
@@ -29,24 +28,9 @@ help_schema = {
 }
 
 
-parameter_fields_no_nesting = {
+parameter_field_schema = {
     "help": help_schema.copy(),
-    "minimize": {"required": False, "type": "boolean"},
-    "shared_parameter_group_uuid": {
-        "required": False,
-        "dependencies": {"type": ["group"]},
-        "type": "string",
-    },
-    "is_collapsible": {
-        "required": False,
-        "dependencies": {"type": ["group"]},
-        "type": "boolean",
-    },
-    "collapsed": {
-        "required": False,
-        "dependencies": {"is_collapsible": [True]},
-        "type": "boolean",
-    },
+    "collapsed": {"required": False, "type": "boolean",},
     "required": {"required": False, "type": "boolean"},
     "choices": {"dependencies": {"type": ["enum"]}, "type": "list"},
     "connection_type_uuid": {"dependencies": {"type": ["connection"]}, "type": "string"},
@@ -80,14 +64,20 @@ parameter_fields_no_nesting = {
     "min": {"required": False, "type": "integer"},
     "default": {"required": False},
 }
-parameter_fields_nesting = {
+parameter_group_schema = {
+    "display_name": {"type": "string", "required": True},
+    "shared_parameter_group_uuid": {
+        "required": False,
+        "dependencies": {"type": ["group"]},
+        "type": "string",
+    },
+    "name": {"type": "string", "required": True},
+    "type": {"allowed": ["group"], "required": True,},
     "parameters": {
         "type": "list",
-        "dependencies": {"type": ["group"]},
-        "schema": {"type": "dict", "schema": parameter_fields_no_nesting.copy()},
-    }
+        "schema": {"type": "dict", "schema": parameter_field_schema.copy()},
+    },
 }
-parameter_fields_nesting.update(parameter_fields_no_nesting)
 
 
 engine_schema = {
@@ -141,7 +131,7 @@ engine_schema = {
                 "parameters": {
                     "type": "list",
                     "required": True,
-                    "schema": {"type": "dict", "schema": parameter_fields_nesting},
+                    "schema": {"type": "dict", "schema": parameter_group_schema},
                 },
             },
         },
@@ -170,7 +160,7 @@ shared_object_type_schema = {
     "type": {"allowed": ["shared_object_type"], "required": True},
     "parameters": {
         "type": "list",
-        "schema": {"type": "dict", "schema": parameter_fields_nesting.copy()},
+        "schema": {"type": "dict", "schema": parameter_field_schema.copy()},
     },
 }
 connection_type_schema = {
@@ -194,7 +184,7 @@ connection_type_schema = {
     "type": {"allowed": ["connection"], "required": True},
     "parameters": {
         "type": "list",
-        "schema": {"type": "dict", "schema": parameter_fields_nesting.copy()},
+        "schema": {"type": "dict", "schema": parameter_field_schema.copy()},
     },
 }
 schemas = {
